@@ -5,6 +5,7 @@ from .core import upload_file
 import os
 import boto3
 import tempfile
+import piphyperd
 
 s3_bucket = os.environ["S3_PYPI"]
 app = typer.Typer()
@@ -48,7 +49,7 @@ def download_install(package_name: str):
             Key= package_key,
             Filename = f"{temp_dir.name}/test.whl")
     print(f"Downloaded package to {temp_dir.name}")
-
+    piphyperd.PipHyperd().install(f"{temp_dir.name}/test.whl")
 
 def main():
     app()
